package friend

import (
	"net/http"

	"git.kirsle.net/apps/gosocial/pkg/config"
	"git.kirsle.net/apps/gosocial/pkg/models"
	"git.kirsle.net/apps/gosocial/pkg/session"
	"git.kirsle.net/apps/gosocial/pkg/templates"
)

// Friends list and pending friend request endpoint.
func Friends() http.HandlerFunc {
	tmpl := templates.Must("friend/friends.html")
	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
		isRequests := r.FormValue("view") == "requests"

		currentUser, err := session.CurrentUser(r)
		if err != nil {
			session.FlashError(w, r, "Unexpected error: could not get currentUser.")
			templates.Redirect(w, "/")
			return
		}

		// Get our friends.
		pager := &models.Pagination{
			PerPage: config.PageSizeFriends,
			Sort:    "updated_at desc",
		}
		pager.ParsePage(r)
		friends, err := models.PaginateFriends(currentUser.ID, isRequests, pager)
		if err != nil {
			session.FlashError(w, r, "Couldn't paginate friends: %s", err)
			templates.Redirect(w, "/")
			return
		}

		var vars = map[string]interface{}{
			"IsRequests": isRequests,
			"Friends":    friends,
			"Pager":      pager,
		}
		if err := tmpl.Execute(w, r, vars); err != nil {
			http.Error(w, err.Error(), http.StatusInternalServerError)
			return
		}
	})
}
